@@ -6,7 +6,7 @@ static PyObject* kmerslib_core_makeFFPS(PyObject *self, PyObject *args){
     int startk;
     int endk;
     int ndevice;
-		if (!PyArg_ParseTuple(args, "ciii",&dir,&startk,&endk, &ndevice))return NULL;
+		if (!PyArg_ParseTuple(args, "siii",&dir,&startk,&endk, &ndevice))return NULL;
 		return Py_BuildValue("i", kmerslib::makeFFPS(dir,startk, endk, ndevice) );
 	}
 
